%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                    ResilientTransportation 1.0                      %%%
%%%                                                                     %%%
%%%         Dr. Bocchini's Research Group at Lehigh University          %%%
%%%                       www.paolobocchini.com                         %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Input characteristics of the nodes of the network

% nodes(in, :) = characterics of node in
% nodes(: , 1) = x position in miles
% nodes(: , 2) = y position in miles
% nodes(: , 3) = number of travels generated by node in during reference period
% nodes(: , 4) = number of travels attracted by node in during reference period

xy = [  2 0
        1 1
        0 2
        3 0
        3 1
        3 2
        4 0
        5 1
        6 2];

O=[ 2 1 2 ...
    1 1 1 ...
    2 1 2]*5000;
D=O;

nodes = [xy,O',D'];
clear xy  O D

%% Input characteristics of the links of the network
     
% links(il, :) = characterics of link il
% links(: , 1) = origin node
% links(: , 2) = destination node
% links(: , 3) = number of directions (1 or 2)
% links(: , 4) = travel time at free flow in minutes (as a rule of thumb, assuming free flow at 60mph, this can be set to a number of minutes equal to the length in miles)
% links(: , 5) = practical capacity (capacity of link per unit of time, as a rule of thumb, this can be set equal to 2000 x number of lanes)
% links(: , 6) = length in miles

OD=[1 2
    2 3
    4 5
    5 6
    7 8
    8 9
    1 4
    4 7
    2 5
    5 8
    3 6
    6 9];
OD2(1:2:24,:)=OD;
OD2(2:2:24,1)=OD(:,2);
OD2(2:2:24,2)=OD(:,1);

distance=sqrt((nodes(OD2(:,1),1)-nodes(OD2(:,2),1)).^2+...
              (nodes(OD2(:,1),2)-nodes(OD2(:,2),2)).^2); %miles        
        
links = [OD2 ones(24,1) distance ones(24,1)*4000 distance];
clear OD OD2 distance

%% Input characteristics the bridges of the network

% bridges(in, :) = characterics of bridge ib
% bridges.carr(: , 1:end) = links carried by the bridge
% bridges.cros(: , 1:end) = links crossed by the bridge
% bridges.d(: , 1:end) = damage condition (0=no damage; 1=minor; 2=moderate; 3=major; 4=collapse)
% bridges.wp(:,1:end) = work progress status (0=repairs not in progress 1=repairs in progress) 
% bridges.n(: , 1:end) = name of the bridge (only for clarity)
% bridges.cd(: , 1:end) = basic detour time
% bridges.dd(: , 1:end) = basic detour distance
% bridges.fd(: , 1:end) = detour practical capacity

%== For more information refere to:

%==> Bocchini, P. and Frangopol, D. M. (2011b).
% A stochastic computational framework for the joint transportation network
% fragility analysis and traffic flow distribution under extreme events.
% Probabilistic Engineering Mechanics, 26(2):182-193.
%==> Bocchini, P. and Frangopol, D. M. (2012).
% Restoration of bridge networks after an earthquake: Multicriteria
% itervention optimization. Earthquake Spectra, 28(2):426-455.

bridges.carr = [ 1  2   %A
                 3  4   %B
                 5  6   %C
                 7  8   %D
                 9 10   %E
                11 12   %F
                21 22   %G
                23 24]; %H
bridges.cros = zeros(8,1);

bridges.d = [   4 
                4
                4
                4
                4 
                4
                0
                0];
            
bridges.wp = [  0 
                0
                0
                0
                0 
                0
                1
                0];            
            
bridges.n={ 'A'
            'B'
            'C'
            'D'
            'E'
            'F'
            'G'
            'H'};
			
			
% Detour time [minutes] = Detour length [km] from NBI / 40 [km/h] * 60 [minutes/h]        
bridges.cd=[1 
            1
            1
            1
            1
            1
            1
            1]/40*60;
			
  
% Detour length [mi] = Detour time [minutes] / 60 [minutes/h] * 40 [km/h] *0.621371192 [mi/km]        
bridges.dd=bridges.cd/60*40*0.621371192;     


bridges.fd=ones(size(bridges.d))*1500;        

%% Input name of the lookup table (for computational efficiency)

% param.nameTotCombFile='lookup_file_name.mat';
param.nameTotCombFile = 'lookup_file_name.mat';

%% Convergence parameters

% conv.toll = tollerance to determine when convergence is met
% conv.tmax = maximum time for the analysis
% conv.itermax = maximum number of iterations

conv.toll=1e-3;   
conv.tmax=1*60;
conv.itermax=5000;  

%% Call the solver (do not edit the following command)

[TTT,TTD] = TA_initiation_01(nodes,links,bridges,conv,param);
